Documentation
¶
Overview ¶
Package mesh provides wireless mesh networking configuration and operational operations for Cisco IOS-XE wireless controllers.
This package allows you to manage mesh networking configurations, operational data, and topology monitoring. It provides methods for mesh topology management, backhaul configuration, and mesh network monitoring.
RESTCONF Endpoints: - Configuration: /restconf/data/Cisco-IOS-XE-wireless-mesh-cfg:mesh-cfg-data - Operational: /restconf/data/Cisco-IOS-XE-wireless-mesh-oper:mesh-oper-data
YANG References: - Cisco-IOS-XE-wireless-mesh-cfg.yang (17.12.1, 17.15.1, 17.18.1) - Cisco-IOS-XE-wireless-mesh-oper.yang (17.12.1, 17.15.1, 17.18.1)
Index ¶
- type CiscoIOSXEWirelessMeshCfgMeshProfiles
- type CiscoIOSXEWirelessMeshOper
- type CiscoIOSXEWirelessMeshOperMeshApCacInfo
- type CiscoIOSXEWirelessMeshOperMeshApPathInfo
- type CiscoIOSXEWirelessMeshOperMeshApTreeData
- type CiscoIOSXEWirelessMeshOperMeshDataRateStats
- type CiscoIOSXEWirelessMeshOperMeshGlobalStats
- type CiscoIOSXEWirelessMeshOperMeshOperational
- type CiscoIOSXEWirelessMeshOperMeshQueueStats
- type CiscoIOSXEWirelessMeshOperMeshSecurityStats
- type Mesh
- type MeshApCacInfo
- type MeshApInfo
- type MeshApPathInfo
- type MeshApTreeData
- type MeshBackhaulDataRate
- type MeshCfg
- type MeshDataRateStats
- type MeshGlobalOper
- type MeshGlobalStats
- type MeshOperational
- type MeshProfile
- type MeshProfiles
- type MeshQueueStats
- type MeshSecurityStats
- type Service
- func (s Service) GetConfig(ctx context.Context) (*MeshCfg, error)
- func (s Service) GetGlobalStats(ctx context.Context) (*CiscoIOSXEWirelessMeshOperMeshGlobalStats, error)
- func (s Service) GetOperational(ctx context.Context) (*CiscoIOSXEWirelessMeshOper, error)
- func (s Service) GetOperationalData(ctx context.Context) (*CiscoIOSXEWirelessMeshOper, error)
- func (s Service) ListApCacInfo(ctx context.Context) (*CiscoIOSXEWirelessMeshOperMeshApCacInfo, error)
- func (s Service) ListApPathInfo(ctx context.Context) (*CiscoIOSXEWirelessMeshOperMeshApPathInfo, error)
- func (s Service) ListApTreeData(ctx context.Context) (*CiscoIOSXEWirelessMeshOperMeshApTreeData, error)
- func (s Service) ListMeshDataRateStats(ctx context.Context) (*CiscoIOSXEWirelessMeshOperMeshDataRateStats, error)
- func (s Service) ListMeshOperationalData(ctx context.Context) (*CiscoIOSXEWirelessMeshOperMeshOperational, error)
- func (s Service) ListMeshQueueStats(ctx context.Context) (*CiscoIOSXEWirelessMeshOperMeshQueueStats, error)
- func (s Service) ListMeshSecurityStats(ctx context.Context) (*CiscoIOSXEWirelessMeshOperMeshSecurityStats, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CiscoIOSXEWirelessMeshCfgMeshProfiles ¶ added in v0.4.0
type CiscoIOSXEWirelessMeshCfgMeshProfiles struct {
MeshProfiles []MeshProfile `json:"Cisco-IOS-XE-wireless-mesh-cfg:mesh-profiles"`
}
CiscoIOSXEWirelessMeshCfgMeshProfiles represents mesh profiles container structure.
type CiscoIOSXEWirelessMeshOper ¶ added in v0.4.0
type CiscoIOSXEWirelessMeshOper struct {
CiscoIOSXEWirelessMeshOperData struct {
MeshQueueStats []MeshQueueStats `json:"mesh-q-stats,omitempty"` // Mesh packet queue statistics (YANG: IOS-XE 17.12.1)
MeshDataRateStats []MeshDataRateStats `json:"mesh-dr-stats,omitempty"` // Mesh data rate statistics (YANG: IOS-XE 17.12.1)
MeshSecurityStats []MeshSecurityStats `json:"mesh-sec-stats,omitempty"` // Mesh security statistics (YANG: IOS-XE 17.12.1)
MeshOperational []MeshOperational `json:"mesh-oper-data,omitempty"` // Mesh operational data (YANG: IOS-XE 17.12.1)
} `json:"Cisco-IOS-XE-wireless-mesh-oper:mesh-oper-data"` // Mesh operational data (YANG: IOS-XE 17.12.1)
}
CiscoIOSXEWirelessMeshOper represents mesh operational data container.
type CiscoIOSXEWirelessMeshOperMeshApCacInfo ¶ added in v0.4.0
type CiscoIOSXEWirelessMeshOperMeshApCacInfo struct {
MeshApCacInfo []MeshApCacInfo `json:"Cisco-IOS-XE-wireless-mesh-global-oper:mesh-ap-cac-info,omitempty"` // Summary of mesh voice call statistics (YANG: IOS-XE 17.12.1)
}
CiscoIOSXEWirelessMeshOperMeshApCacInfo represents mesh AP CAC information wrapper.
type CiscoIOSXEWirelessMeshOperMeshApPathInfo ¶ added in v0.4.0
type CiscoIOSXEWirelessMeshOperMeshApPathInfo struct {
MeshApPathInfo []MeshApPathInfo `json:"Cisco-IOS-XE-wireless-mesh-global-oper:mesh-ap-path-info,omitempty"` // Mesh AP path from root AP to mesh AP (YANG: IOS-XE 17.12.1)
}
CiscoIOSXEWirelessMeshOperMeshApPathInfo represents mesh AP path information wrapper.
type CiscoIOSXEWirelessMeshOperMeshApTreeData ¶ added in v0.4.0
type CiscoIOSXEWirelessMeshOperMeshApTreeData struct {
MeshApTreeData []MeshApTreeData `json:"Cisco-IOS-XE-wireless-mesh-global-oper:mesh-ap-tree-data"` // Mesh AP tree view (Live: IOS-XE 17.12.6a)
}
CiscoIOSXEWirelessMeshOperMeshApTreeData represents mesh AP tree data wrapper.
type CiscoIOSXEWirelessMeshOperMeshDataRateStats ¶ added in v0.4.0
type CiscoIOSXEWirelessMeshOperMeshDataRateStats struct {
MeshDataRateStats []MeshDataRateStats `json:"Cisco-IOS-XE-wireless-mesh-oper:mesh-dr-stats"` // Mesh data rate statistics (YANG: IOS-XE 17.12.1)
}
CiscoIOSXEWirelessMeshOperMeshDataRateStats represents mesh data rate statistics container.
type CiscoIOSXEWirelessMeshOperMeshGlobalStats ¶ added in v0.4.0
type CiscoIOSXEWirelessMeshOperMeshGlobalStats struct {
MeshGlobalStats MeshGlobalStats `json:"Cisco-IOS-XE-wireless-mesh-global-oper:mesh-global-stats"` // Summary of mesh AP statistics (Live: IOS-XE 17.12.6a)
}
CiscoIOSXEWirelessMeshOperMeshGlobalStats represents mesh global statistics wrapper.
type CiscoIOSXEWirelessMeshOperMeshOperational ¶ added in v0.4.0
type CiscoIOSXEWirelessMeshOperMeshOperational struct {
MeshOperational []MeshOperational `json:"Cisco-IOS-XE-wireless-mesh-oper:mesh-oper-data"` // Mesh operational data (YANG: IOS-XE 17.12.1)
}
CiscoIOSXEWirelessMeshOperMeshOperational represents mesh operational data container.
type CiscoIOSXEWirelessMeshOperMeshQueueStats ¶ added in v0.4.0
type CiscoIOSXEWirelessMeshOperMeshQueueStats struct {
MeshQueueStats []MeshQueueStats `json:"Cisco-IOS-XE-wireless-mesh-oper:mesh-q-stats"` // Mesh packet queue statistics (YANG: IOS-XE 17.12.1)
}
CiscoIOSXEWirelessMeshOperMeshQueueStats represents mesh queue statistics container.
type CiscoIOSXEWirelessMeshOperMeshSecurityStats ¶ added in v0.4.0
type CiscoIOSXEWirelessMeshOperMeshSecurityStats struct {
MeshSecurityStats []MeshSecurityStats `json:"Cisco-IOS-XE-wireless-mesh-oper:mesh-sec-stats"` // Mesh security statistics (YANG: IOS-XE 17.12.1)
}
CiscoIOSXEWirelessMeshOperMeshSecurityStats represents mesh security statistics container.
type Mesh ¶ added in v0.4.1
type Mesh struct {
AssocCountAlarmThresh *int `json:"assoc-count-alarm-thresh,omitempty"` // Association count alarm threshold (YANG: IOS-XE 17.12.1)
HighSNRAlarmThresh *int `json:"high-snr-alarm-thresh,omitempty"` // High SNR alarm threshold (YANG: IOS-XE 17.12.1)
LowSNRAlarmThresh *int `json:"low-snr-alarm-thresh,omitempty"` // Low SNR alarm threshold (YANG: IOS-XE 17.12.1)
MaxMAPChildrenAlarmThresh *int `json:"max-map-children-alarm-thresh,omitempty"` // Maximum MAP children alarm threshold (YANG: IOS-XE 17.12.1)
MaxRAPChildrenAlarmThresh *int `json:"max-rap-children-alarm-thresh,omitempty"` // Maximum RAP children alarm threshold (YANG: IOS-XE 17.12.1)
MaxHopAlarmThresh *int `json:"max-hop-alarm-thresh,omitempty"` // Maximum hop alarm threshold (YANG: IOS-XE 17.12.1)
ParentChangeCountAlarmThresh *int `json:"parent-change-count-alarm-thresh,omitempty"` // Parent change count alarm threshold (YANG: IOS-XE 17.12.1)
BackhaulRRMEnabled *bool `json:"bhaul-rrm-enabled,omitempty"` // Backhaul RRM enabled flag (YANG: IOS-XE 17.12.1)
CACEnabled *bool `json:"cac-enabled,omitempty"` // Call Admission Control enabled flag (YANG: IOS-XE 17.12.1)
RAPChannelSyncEnabled *bool `json:"rap-channel-sync-enabled,omitempty"` // RAP channel sync enabled flag (YANG: IOS-XE 17.12.1)
}
Mesh represents global mesh configuration.
type MeshApCacInfo ¶ added in v0.3.2
type MeshApCacInfo struct {
WTPName string `json:"wtp-name"` // AP name (YANG: IOS-XE 17.12.1)
}
MeshApCacInfo represents summary of mesh voice call statistics.
type MeshApInfo ¶ added in v0.3.2
type MeshApInfo struct {
APName string `json:"ap-name"` // AP name (YANG: IOS-XE 17.12.1)
APRole string `json:"ap-role"` // Mesh AP role (YANG: IOS-XE 17.12.1)
BridgeGroupName string `json:"bridge-group-name"` // Bridge group name configured on this Access Point (YANG: IOS-XE 17.12.1)
PrefParentAPName string `json:"pref-parent-ap-name"` // Mesh AP parent (YANG: IOS-XE 17.12.1)
}
MeshApInfo represents mesh AP tree information.
type MeshApPathInfo ¶ added in v0.3.2
type MeshApPathInfo struct {
WTPName string `json:"wtp-name"` // AP name (YANG: IOS-XE 17.12.1)
}
MeshApPathInfo represents mesh AP path from root AP to mesh AP.
type MeshApTreeData ¶ added in v0.3.2
type MeshApTreeData struct {
SectorNumber uint32 `json:"sector-number"` // Sector number (Live: IOS-XE 17.12.6a)
WTPMAC string `json:"wtp-mac"` // MAC address of the mesh AP (Live: IOS-XE 17.12.6a)
MeshApCount uint32 `json:"mesh-ap-count"` // Number of bridge APs (Live: IOS-XE 17.12.6a)
RAPCount uint32 `json:"rap-count"` // Number of root APs (Live: IOS-XE 17.12.6a)
MAPCount uint32 `json:"map-count"` // Number of mesh APs (Live: IOS-XE 17.12.6a)
MeshApList []MeshApInfo `json:"mesh-ap-list,omitempty"` // List of mesh APs with path info (YANG: IOS-XE 17.12.1)
}
MeshApTreeData represents mesh AP tree view.
type MeshBackhaulDataRate ¶ added in v0.3.2
type MeshBackhaulDataRate struct {
Type *string `json:"type,omitempty"` // Backhaul data rate type configuration (YANG: IOS-XE 17.12.1)
Rate *string `json:"rate,omitempty"` // 802.11abg transmission rate setting (YANG: IOS-XE 17.12.1)
Dot11NMCSIndex *uint8 `json:"dot11n-mcs-index,omitempty"` // 802.11n MCS index configuration (YANG: IOS-XE 17.12.1)
Dot11ACMCSIndex *uint8 `json:"dot11ac-mcs-index,omitempty"` // 802.11ac MCS index configuration (YANG: IOS-XE 17.12.1)
SpatialStream *uint8 `json:"spatial-stream,omitempty"` // 802.11ac spatial stream count (YANG: IOS-XE 17.12.1)
Dot11AXMCSIndex *uint8 `json:"dot11ax-mcs-index,omitempty"` // 802.11ax MCS index configuration (YANG: IOS-XE 17.12.1)
Dot11AXSpatialStreamBG *uint8 `json:"dot11ax-spatial-stream-bg,omitempty"` // 802.11ax 2.4GHz spatial stream count (YANG: IOS-XE 17.12.1)
Dot11AXSpatialStreamA *uint8 `json:"dot11ax-spatial-stream-a,omitempty"` // 802.11ax 5GHz spatial stream count (YANG: IOS-XE 17.12.1)
}
MeshBackhaulDataRate represents mesh backhaul data rate configuration.
type MeshCfg ¶ added in v0.3.2
type MeshCfg struct {
MeshCfgData struct {
Mesh *Mesh `json:"mesh,omitempty"` // Global mesh configuration (YANG: IOS-XE 17.12.1)
MeshProfiles MeshProfiles `json:"mesh-profiles"` // Mesh profiles configuration (Live: IOS-XE 17.12.6a)
} `json:"Cisco-IOS-XE-wireless-mesh-cfg:mesh-cfg-data"` // Mesh configuration data (YANG: IOS-XE 17.12.1)
}
MeshCfg represents mesh configuration data.
type MeshDataRateStats ¶ added in v0.3.2
type MeshDataRateStats struct {
WTPMac string `json:"wtp-mac"` // Wireless Termination Point MAC address (YANG: IOS-XE 17.12.1)
NeighborAPMac string `json:"neigh-ap-mac"` // Neighbor access point MAC address (YANG: IOS-XE 17.12.1)
DataRateIndex uint32 `json:"data-rate-index"` // Data rate index value (YANG: IOS-XE 17.12.1)
TxSuccess *uint32 `json:"tx-success,omitempty"` // Successfully transmitted packets (YANG: IOS-XE 17.12.1)
TxAttempts *uint32 `json:"tx-attempts,omitempty"` // Total transmission attempts (YANG: IOS-XE 17.12.1)
}
MeshDataRateStats represents mesh access point data rate statistics.
type MeshGlobalOper ¶ added in v0.3.2
type MeshGlobalOper struct {
MeshGlobalOperData struct {
MeshGlobalStats MeshGlobalStats `json:"mesh-global-stats"` // Summary of mesh AP statistics (Live: IOS-XE 17.12.6a)
MeshApCacInfo []MeshApCacInfo `json:"mesh-ap-cac-info,omitempty"` // Summary of mesh voice call statistics (YANG: IOS-XE 17.12.1)
MeshApPathInfo []MeshApPathInfo `json:"mesh-ap-path-info,omitempty"` // Mesh AP path from root AP to mesh AP (YANG: IOS-XE 17.12.1)
MeshApTreeData []MeshApTreeData `json:"mesh-ap-tree-data"` // Mesh AP tree view (Live: IOS-XE 17.12.6a)
} `json:"Cisco-IOS-XE-wireless-mesh-global-oper:mesh-global-oper-data"` // Mesh global operational data (Live: IOS-XE 17.12.6a)
}
MeshGlobalOper represents mesh global operational data response.
type MeshGlobalStats ¶ added in v0.3.2
type MeshGlobalStats struct {
NumOfBridgeAPs uint32 `json:"num-of-bridge-aps"` // Number of bridge mode APs (Live: IOS-XE 17.12.6a)
NumOfMAPs uint32 `json:"num-of-maps"` // Number of mesh APs (Live: IOS-XE 17.12.6a)
NumOfRAPs uint32 `json:"num-of-raps"` // Number of root APs (Live: IOS-XE 17.12.6a)
NumOfFlexBridgeAPs uint32 `json:"num-of-flex-bridge-aps"` // Number of flex bridge mode APs (Live: IOS-XE 17.12.6a)
NumOfFlexBridgeMAPs uint32 `json:"num-of-flex-bridge-maps"` // Number of flex mesh APs (Live: IOS-XE 17.12.6a)
NumOfFlexBridgeRAPs uint32 `json:"num-of-flex-bridge-raps"` // Number of flex root APs (Live: IOS-XE 17.12.6a)
}
MeshGlobalStats represents statistics of mesh APs joined to the controller.
type MeshOperational ¶ added in v0.3.2
type MeshOperational struct {
WTPMac string `json:"wtp-mac"` // Wireless Termination Point MAC address (YANG: IOS-XE 17.12.1)
BackhaulSlotID *uint8 `json:"bhaul-slot-id,omitempty"` // Backhaul radio slot identifier (YANG: IOS-XE 17.12.1)
BackhaulRateMCSs *uint8 `json:"bhaul-rate-mcs-ss,omitempty"` // Mesh backhaul 802.11ac MCS spatial stream (YANG: IOS-XE 17.12.1)
ActiveTrunkNativeVLAN *uint16 `json:"active-trunk-native-vlan,omitempty"` // Trunk native VLAN (YANG: IOS-XE 17.12.1)
ConfiguredRole *string `json:"configured-role,omitempty"` // Configured AP role (YANG: IOS-XE 17.12.1)
BackhaulRadioMode *string `json:"bhaul-radio-mode,omitempty"` // Backhaul radio mode (YANG: IOS-XE 17.12.1)
APMode *string `json:"ap-mode,omitempty"` // AP mode (YANG: IOS-XE 17.12.1)
APRole *string `json:"ap-role,omitempty"` // Current AP role (YANG: IOS-XE 17.12.1)
BackhaulRadioType *string `json:"bhaul-radio-type,omitempty"` // Backhaul radio type (YANG: IOS-XE 17.12.1)
BackhaulDataRateType *string `json:"bhaul-data-rate-type,omitempty"` // Backhaul data rate type (YANG: IOS-XE 17.12.1)
}
MeshOperational represents mesh access point operational data.
type MeshProfile ¶ added in v0.3.2
type MeshProfile struct {
ProfileName string `json:"profile-name"` // Mesh profile name identifier (Live: IOS-XE 17.12.6a)
Description string `json:"description"` // Mesh profile description (Live: IOS-XE 17.12.6a)
AMSDUEnabled *bool `json:"amsdu-enabled,omitempty"` // AMSDU aggregation enabled flag (YANG: IOS-XE 17.12.1)
BackgroundScanEnabled *bool `json:"bg-scan-enabled,omitempty"` // Background scanning enabled flag (YANG: IOS-XE 17.12.1)
CCNMode *bool `json:"ccn-mode,omitempty"` // Cisco Compatible eXtensions mode (YANG: IOS-XE 17.12.1)
BackhaulClientAccess *bool `json:"bhaul-client-access,omitempty"` // Backhaul client access enabled flag (YANG: IOS-XE 17.12.1)
EthVLANTransparent *bool `json:"eth-vlan-transparent,omitempty"` // Ethernet VLAN transparent mode (YANG: IOS-XE 17.12.1)
SecurityMode *string `json:"security-mode,omitempty"` // Security mode configuration (YANG: IOS-XE 17.12.1)
BridgeGroupName *string `json:"bridgegroupname,omitempty"` // Bridge group name assignment (YANG: IOS-XE 17.12.1)
BGNStrictMatchEnabled *bool `json:"bgn-strict-match-enabled,omitempty"` // Bridge group name strict matching (YANG: IOS-XE 17.12.1)
BackhaulTxRateDot11BG *MeshBackhaulDataRate `json:"bhaul-tx-rate-dot11bg,omitempty"` // Backhaul data rate for 2.4GHz radio (YANG: IOS-XE 17.12.1)
BackhaulTxRateDot11A *MeshBackhaulDataRate `json:"bhaul-tx-rate-dot11a,omitempty"` // Backhaul data rate for 5GHz radio (YANG: IOS-XE 17.12.1)
}
MeshProfile represents individual mesh profile configuration.
type MeshProfiles ¶ added in v0.4.1
type MeshProfiles struct {
MeshProfile []MeshProfile `json:"mesh-profile"`
}
MeshProfiles represents mesh profiles container.
type MeshQueueStats ¶ added in v0.3.2
type MeshQueueStats struct {
WTPMac string `json:"wtp-mac"` // Wireless Termination Point MAC address (YANG: IOS-XE 17.12.1)
QueueType string `json:"q-type"` // Queue type identifier (YANG: IOS-XE 17.12.1)
PeakLength *uint16 `json:"peak-length,omitempty"` // Peak number of packets waiting in queue (YANG: IOS-XE 17.12.1)
AverageLen *uint16 `json:"average-len,omitempty"` // Average number of packets waiting in queue (YANG: IOS-XE 17.12.1)
Overflows *uint16 `json:"overflows,omitempty"` // Number of queue overflows (YANG: IOS-XE 17.12.1)
}
MeshQueueStats represents mesh access point packet queue statistics.
type MeshSecurityStats ¶ added in v0.3.2
type MeshSecurityStats struct {
WTPMac string `json:"wtp-mac"` // Wireless Termination Point MAC address (YANG: IOS-XE 17.12.1)
TxPktsTotal *uint32 `json:"tx-pkts-total,omitempty"` // Total transmitted packets during security negotiation (YANG: IOS-XE 17.12.1)
RxPktsTotal *uint32 `json:"rx-pkts-total,omitempty"` // Total received packets during security negotiation (YANG: IOS-XE 17.12.1)
RxPktsError *uint32 `json:"rx-pkts-error,omitempty"` // Total error packets received during security negotiation (YANG: IOS-XE 17.12.1)
}
MeshSecurityStats represents mesh access point security statistics.
type Service ¶
type Service struct {
service.BaseService
}
Service provides wireless mesh networking operations for Cisco IOS-XE Wireless LAN Controller.
func NewService ¶
NewService creates a new Mesh service instance with the provided client.
func (Service) GetGlobalStats ¶ added in v0.4.0
func (s Service) GetGlobalStats(ctx context.Context) (*CiscoIOSXEWirelessMeshOperMeshGlobalStats, error)
GetGlobalStats retrieves mesh global statistics from the controller.
func (Service) GetOperational ¶
func (s Service) GetOperational(ctx context.Context) (*CiscoIOSXEWirelessMeshOper, error)
GetOperational retrieves all mesh operational data.
func (Service) GetOperationalData ¶
func (s Service) GetOperationalData(ctx context.Context) (*CiscoIOSXEWirelessMeshOper, error)
GetOperationalData retrieves mesh operational data including queue stats, data rate stats, security stats, and operational data.
func (Service) ListApCacInfo ¶ added in v0.4.0
func (s Service) ListApCacInfo(ctx context.Context) (*CiscoIOSXEWirelessMeshOperMeshApCacInfo, error)
ListApCacInfo retrieves mesh AP CAC information from the controller. Note: Based on YANG: IOS-XE 17.12.1 - may not be available on all controller versions.
func (Service) ListApPathInfo ¶ added in v0.4.0
func (s Service) ListApPathInfo(ctx context.Context) (*CiscoIOSXEWirelessMeshOperMeshApPathInfo, error)
ListApPathInfo retrieves mesh AP path information from the controller. Note: Based on YANG: IOS-XE 17.12.1 - may not be available on all controller versions.
func (Service) ListApTreeData ¶ added in v0.4.0
func (s Service) ListApTreeData(ctx context.Context) (*CiscoIOSXEWirelessMeshOperMeshApTreeData, error)
ListApTreeData retrieves mesh AP tree data from the controller.
func (Service) ListMeshDataRateStats ¶ added in v0.3.6
func (s Service) ListMeshDataRateStats(ctx context.Context) (*CiscoIOSXEWirelessMeshOperMeshDataRateStats, error)
ListMeshDataRateStats retrieves mesh data rate statistics from the controller. Note: Based on YANG: IOS-XE 17.12.1 - may not be available on all controller versions.
func (Service) ListMeshOperationalData ¶ added in v0.3.6
func (s Service) ListMeshOperationalData(ctx context.Context) (*CiscoIOSXEWirelessMeshOperMeshOperational, error)
ListMeshOperationalData retrieves mesh operational data from the controller. Note: Based on YANG: IOS-XE 17.12.1 - may not be available on all controller versions.
func (Service) ListMeshQueueStats ¶ added in v0.3.6
func (s Service) ListMeshQueueStats(ctx context.Context) (*CiscoIOSXEWirelessMeshOperMeshQueueStats, error)
ListMeshQueueStats retrieves mesh packet queue statistics from the controller. Note: Based on YANG: IOS-XE 17.12.1 - may not be available on all controller versions.
func (Service) ListMeshSecurityStats ¶ added in v0.3.6
func (s Service) ListMeshSecurityStats(ctx context.Context) (*CiscoIOSXEWirelessMeshOperMeshSecurityStats, error)
ListMeshSecurityStats retrieves mesh security statistics from the controller. Note: Based on YANG: IOS-XE 17.12.1 - may not be available on all controller versions.